@@ -2,14 +2,21 @@
 
 from __future__ import unicode_literals
 
-from django.db import models
-from django.db.models.signals import post_delete, post_save, pre_save
-from django.utils.encoding import python_2_unicode_compatible, force_text
-from django.utils.translation import ugettext_lazy as _
+from admin_interface.cache import del_cached_active_theme
 
 from colorfield.fields import ColorField
 
-from admin_interface.cache import del_cached_active_theme
+import django
+from django.db import models
+from django.db.models.signals import post_delete, post_save, pre_save
+if django.VERSION < (2, 0):
+    from django.utils.encoding import force_text as force_str
+    from django.utils.translation import ugettext_lazy as _
+else:
+    from django.utils.encoding import force_str
+    from django.utils.translation import gettext_lazy as _
+
+from six import python_2_unicode_compatible
 
 
 @python_2_unicode_compatible
@@ -127,6 +134,19 @@ class Theme(models.Model):
         default=True,
         verbose_name=_('visible in favicon (marker)'))
 
+    language_chooser_active = models.BooleanField(
+        default=True,
+        verbose_name=_('active'))
+    language_chooser_display_choices = (
+        ('code', _('code'), ),
+        ('name', _('name'), ),
+    )
+    language_chooser_display = models.CharField(
+        max_length=10,
+        choices=language_chooser_display_choices,
+        default='code',
+        verbose_name=_('display'))
+
     css_header_background_color = ColorField(
         blank=True,
         default='#0C4B33',
@@ -286,7 +306,7 @@ class Theme(models.Model):
         verbose_name_plural = _('Themes')
 
     def __str__(self):
-        return force_text(self.name)
+        return force_str(self.name)
 
 
 post_delete.connect(Theme.post_delete_handler, sender=Theme)
